/*
 * Copyright (C) 2019-2022 CZ.NIC z.s.p.o. (https://www.nic.cz/)
 *
 * This is free software, licensed under the GNU General Public License v3.
 * See /LICENSE for more information.
 */

import React from "react";

import { render, wait } from "customTestRender";
import mockAxios from "jest-mock-axios";

import {
    useCustomizationContext,
    CustomizationContextProvider,
} from "../CustomizationContext";

const CUSTOM = "Description / component for customized reForis (Shield)";
const ORIGINAL = "Description / component for original reForis (other devices)";

function CustomizationTest() {
    const isCustomized = useCustomizationContext();

    return <p>{isCustomized ? CUSTOM : ORIGINAL}</p>;
}

describe("CustomizationContext", () => {
    let componentContainer;

    it("should render component without customization", async () => {
        const { container, getByText } = render(
            <CustomizationContextProvider>
                <CustomizationTest />
            </CustomizationContextProvider>
        );
        componentContainer = container;

        mockAxios.mockResponse({ data: {} });
        await wait(() => getByText(ORIGINAL));

        expect(componentContainer).toMatchSnapshot();
    });

    it("should render customized component", async () => {
        const { container, getByText } = render(
            <CustomizationContextProvider>
                <CustomizationTest />
            </CustomizationContextProvider>
        );
        componentContainer = container;

        mockAxios.mockResponse({ data: { customization: "shield" } });
        await wait(() => getByText(CUSTOM));

        expect(componentContainer).toMatchSnapshot();
    });
});
